@@ -1,4 +1,15 @@
+from os import environ, makedirs
+
+
+user = environ.get('USER')
+dest = environ.get('setux_logdir', '/tmp/setux/log')
+dest = f'{dest}/{user}'
+makedirs(dest, exist_ok=True)
+
+
 config = {
+    'version': 1,
+    'disable_existing_loggers': True,
     'formatters': {
         'stdout': {
             'format': '%(message)s'
@@ -15,14 +26,14 @@ config = {
     'handlers': {
         'debug': {
             'class': 'logging.FileHandler',
-            'filename': '/data/log/setux_debug.log',
+            'filename': f'{dest}/setux_debug.log',
             'formatter': 'full',
             'level': 'DEBUG',
             'mode': 'w'
         },
         'info': {
             'class': 'logging.FileHandler',
-            'filename': '/data/log/setux_info.log',
+            'filename': f'{dest}/setux_info.log',
             'formatter': 'short',
             'level': 'INFO',
             'mode': 'w'
@@ -34,7 +45,7 @@ config = {
         },
         'root': {
             'class': 'logging.FileHandler',
-            'filename': '/data/log/setux_root.log',
+            'filename': f'{dest}/setux_root.log',
             'formatter': 'short',
             'level': 'ERROR',
             'mode': 'w'
@@ -50,6 +61,4 @@ config = {
     'root': {
         'handlers': ['root'], 'level': 'NOTSET'
     },
-    'version': 1,
-    'disable_existing_loggers': True,
- }
+}
